# File Access Via Webform

- Secure file downloads via webforms
- Configurable download behavior
- Token-based access control

## Overview

This module provides secure file access control through webforms. It implements
token-based security for downloads with configurable options, including modal
dialogs and customizable messages. Protect sensitive files while maintaining a
user-friendly experience.

## Features

- Secure file downloads with token-based access
- Configurable download behavior (inline viewing vs. force download)
- Webform integration for controlled file access
- Customizable download messages
- Optional Bootstrap 4 Modal integration
- Field formatter for file fields
- Support for both direct file fields and media document references

## Requirements

- Drupal 10 or 11
- Webform module
- Bootstrap 4 Modal module (optional)

## Installation

1. Install the module using Composer:
   ```bash
   composer require drupal/file_access_via_webform
   ```
2. Enable the module through the Drupal admin interface or using Drush:
   ```bash
   drush en file_access_via_webform
   ```

## Configuration

### Field Formatter Settings

1. Go to the field settings for your file field 
(Structure > Content types > [Your Content Type] > Manage display)
2. Under "Manage display", set the formatter to "Webform Download Button"
3. Configure the formatter settings:
   - Modal width: Set the width of the modal dialog (e.g., "800px" or "90%")
   - Download link text: Customize the button text
   - Show dialog header: Toggle the visibility of the modal header
   - Show dialog header title: Toggle the visibility of the title in the header
   - Webform: Select the webform to use for the download process

### Webform Handler Settings

1. Add the "File Access Download Redirect" handler to your webform
2. Configure the handler settings:
   - File disposition: Choose between inline display or force download
   - Download message: Customize the message shown after download
   - File URL security: Choose between standard or enhanced security
   - Debug mode: Enable for development purposes

### Download Settings

The module supports the following download settings:

- `disposition`: Controls how the file is delivered
  - `attachment`: Forces file download
  - `inline`: Displays file in browser (default)
- `hide_file_url`: Controls URL security
  - `true`: Uses secure token-based download route
  - `false`: Uses direct file URLs

## Integration

To use this module with your webform:

1. Create a webform with necessary fields for user information.
2. Add the "File Access Download Redirect" handler to your webform.
3. Configure the handler settings to match your security requirements.
4. Add your file field to content using the "Webform Download Button" formatter.

### Field Formatter

The `WebformDownloadFormatter` provides a field formatter for file fields that:
- Modal dialog integration
- Customizable button text
- Bootstrap 4 Modal support
- Webform integration

### Webform Handler

The `WebformDownloadRedirectHandler` provides webform integration with:
- Configurable download behavior
- Custom download messages
- Enhanced security options
- Debug mode for development

## Contributing

We welcome contributions! Please feel free to:

1. Report issues in the [issue queue](https://www.drupal.org/project/issues/file_access_via_webform)
2. Submit patches through the [issue queue](https://www.drupal.org/project/issues/file_access_via_webform)
3. Review and test patches
4. Help with documentation

## Support

- For bug reports and feature requests, please use the [issue queue](https://www.drupal.org/project/issues/file_access_via_webform)
- For general questions, please use the [project page](https://www.drupal.org/project/file_access_via_webform)
